Package: ATbounds
Type: Package
Title: Bounding Treatment Effects by Limited Information Pooling
Version: 0.1.1
Authors@R: c(
    person("Sokbae", "Lee", email = "sl3841@columbia.edu", role = c("aut", "cre")),
    person("Martin", "Weidner", email = "martin.weidner@economics.ox.ac.uk", role = "aut"))
Description: Estimation and inference methods for bounding average treatment effects (on the treated) that are valid under an unconfoundedness assumption. 
    The bounds are designed to be robust in challenging situations, for example, when the conditioning variables take on a large number of different values in the observed sample, or when the overlap condition is violated. 
    This robustness is achieved by only using limited "pooling" of information across observations. 
    For more details, see the paper by Lee and Weidner, "Bounding Treatment Effects by Pooling Limited Information across Observations," forthcoming at the Journal of Econometrics, <doi:10.48550/arXiv.2111.05243>.
License: GPL-3
Encoding: UTF-8
LazyData: true
RoxygenNote: 7.1.2
Imports: stats, mgcv
Suggests: knitr, rmarkdown, testthat, ggplot2
VignetteBuilder: knitr
Depends: R (>= 2.10)
URL: https://github.com/ATbounds/ATbounds-r/,
        https://github.com/ATbounds/ATbounds-replication
BugReports: https://github.com/ATbounds/ATbounds-r/issues
NeedsCompilation: no
Packaged: 2026-05-07 22:30:18 UTC; sokbaelee
Author: Sokbae Lee [aut, cre],
  Martin Weidner [aut]
Maintainer: Sokbae Lee <sl3841@columbia.edu>
Repository: CRAN
Date/Publication: 2026-05-07 22:52:04 UTC
Built: R 4.6.0; ; 2026-05-08 01:48:33 UTC; unix
